elephant.test.test_csd module — Elephant 0.5.0 documentation

# elephant.test.test_csd module

Unit tests for the kCSD methods

This was written by : Chaitanya Chintaluri, Laboratory of Neuroinformatics, Nencki Institute of Exprimental Biology, Warsaw.

license: | Modified BSD, see LICENSE.txt for details.

class `elephant.test.test_csd.` `CSD1D_TestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `setUp`()
  `test_inputs_deltasplineicsd`()
  `test_inputs_standardcsd`()
  `test_inputs_stepicsd`()
  `test_inuts_kcsd`()
  `test_validate_inputs`()

class `elephant.test.test_csd.` `CSD2D_TestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `setUp`()
  `test_kcsd2d_init`()

class `elephant.test.test_csd.` `CSD3D_TestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `setUp`()
  `test_kcsd2d_init`()

class `elephant.test.test_csd.` `LFP_TestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `test_lfp1d_electrodes`()
  `test_lfp2d_electrodes`()
  `test_lfp3d_electrodes`()